@@ -1,5 +1,9 @@
 import os
 from .bmw_file import BMWFile
+from .bmw_backup_file import BMWBackupFile
+from .bmw_info_file import BMWInfoFile
+from .bmw_data_1_file import BMWData1File
+from .bmw_data_1_count_file import BMWData1CountFile
 
 
 class BMWFileFactory:
@@ -30,6 +34,18 @@ class BMWFileFactory:
         """
         _, file_extension = os.path.splitext(filename.upper())
 
+        if filename.upper().endswith("BMWBACKUP.VER"):
+            return BMWBackupFile(filename)
+
+        if filename.upper().endswith("INFO"):
+            return BMWInfoFile(filename)
+
+        if filename.upper().endswith("DATA_1"):
+            return BMWData1File(filename)
+
+        if filename.upper().endswith("DATA_1_COUNT"):
+            return BMWData1CountFile(filename)
+
         if file_extension in cls.ext_map:
             return BMWFile(filename, *cls.ext_map[file_extension])
 
